@@ -30,7 +30,7 @@ class Specification:
 
     def get_dict(self):
         return {
-            'type': self.type_,
+            'type': self.type_.value,
             'name': self.name,
             'description': self.description,
             'required': self.required
@@ -349,7 +349,7 @@ class DeveloperProgramResource(APIResource):
             'readable_name': readable_name,
             'operation_id': operation_id,
             'description': description,
-            'credits_': credits_,
+            'credits': credits_,
             'group_name': group_name,
             'input_specification': [],
             'input_examples': input_examples,
